@@ -13,11 +13,12 @@ module Yast
       @EX = { "target" => { "bash_output" => {} } }
 
       # just returns true because of non-installation mode
-      Testsuite.Test(->() { ProductProfile.CheckCompliance(nil) }, [
-        @READ,
-        {},
-        @EX
-      ], 0)
+      Testsuite.Test(->() { ProductProfile.CheckCompliance(nil) },
+        [
+          @READ,
+          {},
+          @EX
+        ], 0)
 
       Testsuite.Test(->() { ProductProfile.compliance_checked }, [], 0)
 
@@ -27,17 +28,19 @@ module Yast
       ProductProfile.compliance_checked = { 1 => true }
 
       # exits on compliance_checked test
-      Testsuite.Test(->() { ProductProfile.CheckCompliance(nil) }, [
-        @READ,
-        {},
-        @EX
-      ], 0)
+      Testsuite.Test(->() { ProductProfile.CheckCompliance(nil) },
+        [
+          @READ,
+          {},
+          @EX
+        ], 0)
 
-      Testsuite.Test(->() { ProductProfile.CheckCompliance(1) }, [
-        @READ,
-        {},
-        @EX
-      ], 0)
+      Testsuite.Test(->() { ProductProfile.CheckCompliance(1) },
+        [
+          @READ,
+          {},
+          @EX
+        ], 0)
 
       # this would continue to IsCompliant and initialize Pkg::
       # Testsuite::Test (``(ProductProfile::CheckCompliance (2)), [ READ, $[], EX ], 0);
