@@ -3,13 +3,9 @@ require "yast"
 
 module Yast
   describe ".etc.xinetd_conf.services" do
-    before :each do
+    around :each do |example|
       root = File.join(File.dirname(__FILE__), "test_root")
-      change_scr_root(root)
-    end
-
-    after :each do
-      reset_scr_root
+      change_scr_root(root, &example)
     end
 
     describe ".Read" do
