@@ -31,6 +31,9 @@
 #
 # $Id$
 require "yast"
+require "cgi"
+require "packages/commit_result"
+require "packages/update_messages_view"
 
 module Yast
   class PackagesUIClass < Module
@@ -44,6 +47,7 @@ module Yast
       Yast.import "HTML"
       Yast.import "String"
       Yast.import "Popup"
+      Yast.import "Report"
 
       @package_summary = {}
     end
@@ -150,7 +154,7 @@ module Yast
           HSpacing(size_x),
           # dialog heading, %1 is package name
           Heading(Builtins.sformat(_("Confirm Package License: %1"), package)),
-          HBox(VSpacing(size_y), RichText(Id(:lic), license)),
+          HBox(VSpacing(size_y), RichText(Id(:lic), format_license(license))),
           VSpacing(1),
           HBox(
             PushButton(Id(:help), Label.HelpButton),
@@ -215,6 +219,23 @@ module Yast
       ret
     end
 
+    # format the license so it's displayed the same way as in the libyui-qt-pkg dialog,
+    # (see https://github.com/libyui/libyui-qt-pkg/blob/master/src/YQPkgObjList.cc#L1411
+    # https://github.com/libyui/libyui-qt-pkg/blob/master/src/YQPkgTextDialog.cc#L295 )
+    # @param [String] license the raw license text obtained from libzypp
+    # @return [String] formatted license for displaying in a RichText widget
+    def format_license(license)
+      # check the flag for a preformatted HTML
+      return license.dup if license.include?("<!-- DT:Rich -->")
+
+      ret = CGI.escapeHTML(license)
+
+      # two empty lines mean a new paragraph
+      ret.gsub!("\n\n", "</p><p>")
+
+      "<p>" + ret + "</p>"
+    end
+
     # Run helper function, reads the display_support_status feature from the control file
     # @return [Boolean] the read value
     def ReadSupportStatus
@@ -293,7 +314,7 @@ module Yast
 
       UI.OpenDialog(
         Opt(:defaultsize),
-        if widget_options.size > 0 # FIXME: add empty? method to Yast::Term
+        if !widget_options.empty?
           PackageSelector(Id(:packages), widget_options, "")
         else
           PackageSelector(Id(:packages), "")
@@ -525,7 +546,7 @@ module Yast
       if Ops.greater_than(
         Builtins.size(Ops.get_list(summary, "remaining", [])),
         0
-        )
+      )
         items = Builtins.add(
           items,
           Ops.add(
@@ -655,11 +676,12 @@ module Yast
       dialog = VBox(
         RichText(Id(:rtext), summary_str),
         Left(
-          ComboBox(Id(:action), _("After Installing Packages"), [
-            Item(Id("summary"), _("Show This Report"), current_action == "summary"),
-            Item(Id("close"), _("Finish"), current_action == "close"),
-            Item(Id("restart"), _("Continue in the Software Manager"), current_action == "restart")
-          ])
+          ComboBox(Id(:action), _("After Installing Packages"),
+            [
+              Item(Id("summary"), _("Show This Report"), current_action == "summary"),
+              Item(Id("close"), _("Finish"), current_action == "close"),
+              Item(Id("restart"), _("Continue in the Software Manager"), current_action == "restart")
+            ])
         )
       )
 
@@ -756,6 +778,20 @@ module Yast
       ShowInstallationSummaryMap(@package_summary)
     end
 
+    # Show messages coming from libzypp about installed packages
+    #
+    # This messages are retrieved from libzypp.
+    #
+    # @param [Array] result Result from package commit (as it comes from PkgCommit)
+    def show_update_messages(result)
+      return false if result.nil?
+      commit_result = ::Packages::CommitResult.from_result(result)
+      return false if commit_result.update_messages.empty?
+      view = ::Packages::UpdateMessagesView.new(commit_result.update_messages)
+      Report.LongMessage(view.richtext)
+      true
+    end
+
     publish function: :GetPackageSummary, type: "map <string, any> ()"
     publish function: :SetPackageSummary, type: "void (map <string, any>)"
     publish function: :ResetPackageSummary, type: "void ()"
